# django-utility

A Django application that provides generic utility.

- [django-utility](#django-utility)
  - [Installation](#installation)
  - [Reference](#reference)

## Installation

```bash
pip install django-utility
```

## Reference

<https://docs.djangoproject.com/en/4.2/intro/reusable-apps/>
